@@ -114,6 +114,7 @@ class EventManager:
 
         item_id = self.parameters.get('itemId')
         user_id = self.parameters.get('userId')
+        timestamp = self.parameters.get('timestamp', int(time.time()))
 
         try:
             personalize_events = boto3.client('personalize-events')
@@ -124,7 +125,7 @@ class EventManager:
                 sessionId=user_id,
                 eventList=[
                     {
-                        'sentAt': int(time.time()),
+                        'sentAt': timestamp,
                         'eventType': event_type,
                         'properties': json.dumps(
                             {
