@@ -55,15 +55,7 @@ class RecommendationsManager:
                 raise Exception('ServerError: Could not determine campaign for this client')
 
             campaign_arn = campaign['arn']
-
-            if not campaign.get('default_results'):
-                print('Saving default results')
-                default_results = self.save_default_results(
-                    client_id=client['id'],
-                    campaign_arn=campaign_arn
-                )
-            else:
-                default_results = campaign['default_results']
+            default_results = campaign.get('default_results', [])
 
             results = self.get_results(
                 client=client,
@@ -97,7 +89,10 @@ class RecommendationsManager:
                     'domain': domain,
                     'item_id': item_id,
                     'session_hash': session_hash,
-                    'results': results}}}
+                    'results': results
+                }
+            }
+        }
 
         print(json.dumps(trigger_log))
 
@@ -160,58 +155,6 @@ class RecommendationsManager:
 
         return None
 
-    def save_default_results(self, *, client_id: int, campaign_arn: str) -> list:
-        """
-            Save default recommendation results to the subscription
-
-            args:
-                client_id (int): The id of the client in the database
-                campaign_arn (str): The AWS Personalize campaign ARN
-
-            returns:
-                results (list): Results from the Personalize invocation
-
-        """
-        results = []
-        service_id = self.service['id']
-
-        subscription_properties = self.query_helper.get_subscription_properties(
-            client_id=client_id,
-            service_id=service_id,
-            from_cache=False
-        )
-
-        if subscription_properties:
-            try:
-                personalize_runtime = boto3.client('personalize-runtime')
-
-                response = personalize_runtime.get_recommendations(
-                    campaignArn=campaign_arn,
-                    itemId='notinmodel'
-                )
-            except Exception as ex:
-                raise Exception('ServerError: {exception}'.format(exception=str(ex)))
-
-            for item in response['itemList']:
-                results.append(item['itemId'])
-
-            campaigns = subscription_properties['campaigns']
-            campaign_index = None
-            for campaign_index, campaign in enumerate(campaigns):
-                if campaign['arn'] == campaign_arn:
-                    break
-
-            if campaign_index:
-                subscription_properties['campaigns'][campaign_index]['default_results'] = results
-
-            self.query_helper.update_subscription_properties(
-                client_id=client_id,
-                service_id=service_id,
-                properties=json.dumps(subscription_properties)
-            )
-
-        return results
-
     def get_results(self, *, client: dict, campaign_arn: str, default_results: list) -> list:
         """
             Determine the results for this request
@@ -262,10 +205,6 @@ class RecommendationsManager:
                     'which probably means default results are out of sync. Saving default results'
                     .format(client_name=client['name'])
                 )
-                self.save_default_results(
-                    client_id=client['id'],
-                    campaign_arn=campaign_arn
-                )
 
             results = []
 
